emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r111105: gmm-utils.el (gmm-called-int


From: Katsumi Yamaoka
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r111105: gmm-utils.el (gmm-called-interactively-p): New function.
Date: Wed, 05 Dec 2012 09:24:27 +0000
User-agent: Bazaar (2.5.0)

------------------------------------------------------------
revno: 111105
committer: Katsumi Yamaoka <address@hidden>
branch nick: trunk
timestamp: Wed 2012-12-05 09:24:27 +0000
message:
  gmm-utils.el (gmm-called-interactively-p): New function.
  gnus-art.el (article-unsplit-urls)
  gnus-bookmark.el (gnus-bookmark-bmenu-list)
  gnus-registry.el (gnus-registry-get-article-marks)
  message.el (message-goto-body): Use it.
    (message-called-interactively-p): Remove.
modified:
  lisp/gnus/ChangeLog
  lisp/gnus/gmm-utils.el
  lisp/gnus/gnus-art.el
  lisp/gnus/gnus-bookmark.el
  lisp/gnus/gnus-registry.el
  lisp/gnus/message.el
=== modified file 'lisp/gnus/ChangeLog'
--- a/lisp/gnus/ChangeLog       2012-12-05 02:26:15 +0000
+++ b/lisp/gnus/ChangeLog       2012-12-05 09:24:27 +0000
@@ -1,5 +1,12 @@
 2012-12-05  Katsumi Yamaoka  <address@hidden>
 
+       * gmm-utils.el (gmm-called-interactively-p): New function.
+       * gnus-art.el (article-unsplit-urls)
+       * gnus-bookmark.el (gnus-bookmark-bmenu-list)
+       * gnus-registry.el (gnus-registry-get-article-marks)
+       * message.el (message-goto-body): Use it.
+       (message-called-interactively-p): Remove.
+
        * gmm-utils.el (gmm-flet): Restore it using cl-letf.
        * gnus-sync.el (gnus-sync-lesync-call)
        * message.el (message-read-from-minibuffer): Use it.

=== modified file 'lisp/gnus/gmm-utils.el'
--- a/lisp/gnus/gnus-art.el     2012-11-08 23:49:58 +0000
+++ b/lisp/gnus/gnus-art.el     2012-12-05 09:24:27 +0000
@@ -45,6 +45,7 @@
 (require 'mm-uu)
 (require 'message)
 (require 'mouse)
+(require 'gmm-utils)
 
 (autoload 'gnus-msg-mail "gnus-msg" nil t)
 (autoload 'gnus-button-mailto "gnus-msg")
@@ -2718,7 +2719,7 @@
       (while (re-search-forward
              "\\(\\(https?\\|ftp\\)://\\S-+\\) *\n\\(\\S-+\\)" nil t)
        (replace-match "\\1\\3" t)))
-    (when (interactive-p)
+    (when (gmm-called-interactively-p 'any)
       (gnus-treat-article nil))))
 
 (defun article-wash-html ()

=== modified file 'lisp/gnus/gnus-bookmark.el'
--- a/lisp/gnus/gnus-bookmark.el        2012-01-19 07:21:25 +0000
+++ b/lisp/gnus/gnus-bookmark.el        2012-12-05 09:24:27 +0000
@@ -53,6 +53,7 @@
 ;;; Code:
 
 (require 'gnus-sum)
+(require 'gmm-utils)
 
 ;; FIXME: should avoid using C-c (no?)
 ;; (define-key gnus-summary-mode-map "\C-crm" 'gnus-bookmark-set)
@@ -367,7 +368,7 @@
 deletion, or > if it is flagged for displaying."
   (interactive)
   (gnus-bookmark-maybe-load-default-file)
-  (if (interactive-p)
+  (if (gmm-called-interactively-p 'any)
       (switch-to-buffer (get-buffer-create "*Gnus Bookmark List*"))
     (set-buffer (get-buffer-create "*Gnus Bookmark List*")))
   (let ((inhibit-read-only t)

=== modified file 'lisp/gnus/gnus-registry.el'
--- a/lisp/gnus/gnus-registry.el        2012-08-31 04:39:30 +0000
+++ b/lisp/gnus/gnus-registry.el        2012-12-05 09:24:27 +0000
@@ -86,6 +86,7 @@
 (require 'nnmail)
 (require 'easymenu)
 (require 'registry)
+(require 'gmm-utils)
 
 (defvar gnus-adaptive-word-syntax-table)
 
@@ -982,7 +983,7 @@
   (let* ((article (last articles))
          (id (gnus-registry-fetch-message-id-fast article))
          (marks (when id (gnus-registry-get-id-key id 'mark))))
-    (when (interactive-p)
+    (when (gmm-called-interactively-p 'interactive)
       (gnus-message 1 "Marks are %S" marks))
     marks))
 

=== modified file 'lisp/gnus/message.el'
--- a/lisp/gnus/message.el      2012-12-05 02:26:15 +0000
+++ b/lisp/gnus/message.el      2012-12-05 09:24:27 +0000
@@ -3137,22 +3137,10 @@
   (push-mark)
   (message-position-on-field "Summary" "Subject"))
 
-(eval-when-compile
-  (defmacro message-called-interactively-p (kind)
-    (condition-case nil
-       (progn
-         (eval '(called-interactively-p 'any))
-         ;; Emacs >=23.2
-         `(called-interactively-p ,kind))
-      ;; Emacs <23.2
-      (wrong-number-of-arguments '(called-interactively-p))
-      ;; XEmacs
-      (void-function '(interactive-p)))))
-
 (defun message-goto-body ()
   "Move point to the beginning of the message body."
   (interactive)
-  (when (and (message-called-interactively-p 'any)
+  (when (and (gmm-called-interactively-p 'any)
             (looking-at "[ \t]*\n"))
     (expand-abbrev))
   (push-mark)


reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- a/lisp/gnus/gmm-utils.el    2012-12-05 02:26:15 +0000
+++ b/lisp/gnus/gmm-utils.el    2012-12-05 09:24:27 +0000
@@ -417,7 +417,19 @@
        (write-region start end filename append visit lockname))
     (write-region start end filename append visit lockname mustbenew)))
 
-;; `flet' and `labels' got obsolete since Emacs 24.3.
+;; `interactive-p' is obsolete since Emacs 23.2.
+(defalias 'gmm-called-interactively-p
+  (condition-case nil
+      (progn
+       (eval '(called-interactively-p 'any))
+       ;; Emacs >=23.2
+       'called-interactively-p)
+    ;; Emacs <23.2
+    (wrong-number-of-arguments '(lambda (kind) (called-interactively-p)))
+    ;; XEmacs
+    (void-function '(lambda (kind) (interactive-p)))))
+
+;; `flet' and `labels' are obsolete since Emacs 24.3.
 (defmacro gmm-flet (bindings &rest body)
   "Make temporary overriding function definitions.
 This is an analogue of a dynamically scoped `let' that operates on

=== modified file 'lisp/gnus/gnus-art.el'